@@ -1,14 +1,15 @@
 package DateTime::Format::Builder::Parser::Quick;
-{
-  $DateTime::Format::Builder::Parser::Quick::VERSION = '0.81';
-}
+
 use strict;
 use warnings;
+
+our $VERSION = '0.82';
+
 use vars qw( %dispatch_data );
+
 use Params::Validate qw( SCALAR OBJECT CODEREF validate );
-use base qw( DateTime::Format::Builder::Parser );
-
 
+use parent qw( DateTime::Format::Builder::Parser );
 
 __PACKAGE__->valid_params(
     Quick => {
@@ -50,13 +51,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::Format::Builder::Parser::Quick - Use another formatter, simply
 
 =head1 VERSION
 
-version 0.81
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -105,10 +108,6 @@ In any case, the resultant code ends up looking like:
 
      my $rv = $Quick->$method( $date );
 
-=head1 SUPPORT
-
-See L<DateTime::Format::Builder> for details.
-
 =head1 SEE ALSO
 
 C<datetime@perl.org> mailing list.
@@ -118,6 +117,16 @@ http://datetime.perl.org/
 L<perl>, L<DateTime>,
 L<DateTime::Format::Builder>
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Format-Builder> or via email to L<bug-datetime-format-builder@rt.cpan.org|mailto:bug-datetime-format-builder@rt.cpan.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-Format-Builder can be found at L<https://github.com/houseabsolute/DateTime-Format-Builder>.
+
 =head1 AUTHORS
 
 =over 4
@@ -134,10 +143,13 @@ Iain Truskett
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2019 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
