@@ -1,16 +1,13 @@
 package DateTime::Format::Builder::Parser::Regex;
-{
-  $DateTime::Format::Builder::Parser::Regex::VERSION = '0.81';
-}
-
 
 use strict;
 use warnings;
-use vars qw( @ISA );
+
+our $VERSION = '0.82';
+
 use Params::Validate qw( validate ARRAYREF SCALARREF HASHREF CODEREF );
 
-use DateTime::Format::Builder::Parser::generic;
-@ISA = qw( DateTime::Format::Builder::Parser::generic );
+use parent 'DateTime::Format::Builder::Parser::generic';
 
 __PACKAGE__->valid_params(
 
@@ -36,7 +33,7 @@ __PACKAGE__->valid_params(
         callbacks => {
             'array has 2 elements' => sub {
                 ref( $_[0] ) eq 'ARRAY' ? ( @{ $_[0] } == 2 ) : 1;
-                }
+            }
         }
     },
 );
@@ -102,13 +99,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::Format::Builder::Parser::Regex - Regex based date parsing
 
 =head1 VERSION
 
-version 0.81
+version 0.82
 
 =head1 SYNOPSIS
 
@@ -169,10 +168,6 @@ it likes. So long as it's 'true'.
 
 =back
 
-=head1 SUPPORT
-
-See L<DateTime::Format::Builder> for details.
-
 =head1 SEE ALSO
 
 C<datetime@perl.org> mailing list.
@@ -182,6 +177,16 @@ http://datetime.perl.org/
 L<perl>, L<DateTime>,
 L<DateTime::Format::Builder>
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Format-Builder> or via email to L<bug-datetime-format-builder@rt.cpan.org|mailto:bug-datetime-format-builder@rt.cpan.org>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-Format-Builder can be found at L<https://github.com/houseabsolute/DateTime-Format-Builder>.
+
 =head1 AUTHORS
 
 =over 4
@@ -198,10 +203,13 @@ Iain Truskett
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2019 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
